@@ -34,13 +34,16 @@
  * SUCH DAMAGE.
  */
 
+#include "tftpsubs.h"
+
 #ifndef lint
-static const char *copyright =
+static const char *copyright UNUSED =
 "@(#) Copyright (c) 1983, 1993\n\
 	The Regents of the University of California.  All rights reserved.\n";
 /* static char sccsid[] = "@(#)main.c	8.1 (Berkeley) 6/6/93"; */
 /* static char rcsid[] = "$OpenBSD: main.c,v 1.4 1997/01/17 07:13:30 millert Exp $"; */
-static const char *rcsid = "tftp-hpa $Id: main.c,v 1.4 2001/03/30 01:30:49 hpa Exp $";
+static const char *rcsid UNUSED =
+ "tftp-hpa $Id: main.c,v 1.6 2001/07/21 02:02:44 hpa Exp $";
 #endif /* not lint */
 
 /* Many bug fixes are from Jim Guyton <guyton@rand-unix> */
@@ -66,17 +69,8 @@ static const char *rcsid = "tftp-hpa $Id: main.c,v 1.4 2001/03/30 01:30:49 hpa E
 #include <string.h>
 #include <unistd.h>
 
-#include "../config.h"
 #include "extern.h"
 
-void bsd_signal(int, void (*)(int));
-
-#ifndef HAVE_SIGSETJMP
-#define sigsetjmp(x,y)  setjmp(x)
-#define siglongjmp(x,y) longjmp(x,y)
-#define sigjmp_buf jmp_buf
-#endif
-
 #define	TIMEOUT		5		/* secs between rexmt's */
 #define	LBUFLEN		200		/* size of input buffer */
 
@@ -152,7 +146,7 @@ struct cmd cmdtab[] = {
 	{ "rexmt",	xhelp,		setrexmt },
 	{ "timeout",	ihelp,		settimeout },
 	{ "?",		hhelp,		help },
-	{ 0 }
+	{ 0, 0, 0 }
 };
 
 struct	cmd *getcmd(char *);
@@ -291,14 +285,14 @@ modecmd(int argc, char *argv[])
 void
 setbinary(int argc, char *argv[])
 {      
-
+	(void)argc; (void)argv;	/* Quiet unused warning */
 	settftpmode("octet");
 }
 
 void
 setascii(int argc, char *argv[])
 {
-
+	(void)argc; (void)argv;	/* Quiet unused warning */
 	settftpmode("netascii");
 }
 
@@ -541,6 +535,7 @@ settimeout(int argc, char *argv[])
 void
 status(int argc, char *argv[])
 {
+	(void)argc; (void)argv;	/* Quiet unused warning */
 	if (connected)
 		printf("Connected to %s.\n", hostname);
 	else
@@ -554,6 +549,7 @@ status(int argc, char *argv[])
 void
 intr(int sig)
 {
+	(void)sig;	/* Quiet unused warning */
 
 	bsd_signal(SIGALRM, SIG_IGN);
 	alarm(0);
@@ -668,7 +664,7 @@ makeargv(void)
 void
 quit(int argc, char *argv[])
 {
-
+	(void)argc; (void)argv;	/* Quiet unused warning */
 	exit(0);
 }
 
@@ -702,6 +698,8 @@ help(int argc, char *argv[])
 void
 settrace(int argc, char *argv[])
 {
+	(void)argc; (void)argv;	/* Quiet unused warning */
+
 	trace = !trace;
 	printf("Packet tracing %s.\n", trace ? "on" : "off");
 }
@@ -709,6 +707,8 @@ settrace(int argc, char *argv[])
 void
 setverbose(int argc, char *argv[])
 {
+	(void)argc; (void)argv;	/* Quiet unused warning */
+
 	verbose = !verbose;
 	printf("Verbose mode %s.\n", verbose ? "on" : "off");
 }
