@@ -1,4 +1,4 @@
-/* $Id: tftp.c,v 1.3 2001/03/30 01:30:49 hpa Exp $ */
+/* $Id: tftp.c,v 1.4 2001/07/21 01:54:26 hpa Exp $ */
 
 /* $OpenBSD: tftp.c,v 1.4 1997/08/06 06:43:45 deraadt Exp $	*/
 /* $NetBSD: tftp.c,v 1.5 1995/04/29 05:55:25 cgd Exp $	*/
@@ -36,10 +36,13 @@
  * SUCH DAMAGE.
  */
 
+#include "tftpsubs.h"
+
 #ifndef lint
 /* static char sccsid[] = "@(#)tftp.c	8.1 (Berkeley) 6/6/93"; */
 /* static char rcsid[] = "$OpenBSD: tftp.c,v 1.4 1997/08/06 06:43:45 deraadt Exp $"; */
-static const char *rcsid = "tftp-hpa $Id: tftp.c,v 1.3 2001/03/30 01:30:49 hpa Exp $";
+static const char *rcsid UNUSED =
+"tftp-hpa $Id: tftp.c,v 1.4 2001/07/21 01:54:26 hpa Exp $";
 #endif /* not lint */
 
 /* Many bug fixes are from Jim Guyton <guyton@rand-unix> */
@@ -64,7 +67,6 @@ static const char *rcsid = "tftp-hpa $Id: tftp.c,v 1.3 2001/03/30 01:30:49 hpa E
 
 #include "../config.h"
 #include "extern.h"
-#include "tftpsubs.h"
 
 void bsd_signal(int, void (*)(int));
 
@@ -449,6 +451,8 @@ timer(int sig)
 {
 	int save_errno = errno;
 
+	(void)sig;		/* Shut up unused warning */
+
 	timeout += rexmtval;
 	if (timeout >= maxtimeout) {
 		printf("Transfer timed out.\n");
