@@ -1,4 +1,4 @@
-/* $Id: tftpsubs.h,v 1.2 2001/07/10 04:52:06 hpa Exp $ */
+/* $Id: tftpsubs.h,v 1.5 2001/07/21 02:02:44 hpa Exp $ */
 
 /* $OpenBSD: tftpsubs.h,v 1.2 1996/06/26 05:40:37 deraadt Exp $	*/
 /* $NetBSD: tftpsubs.h,v 1.2 1994/12/08 09:51:32 jtc Exp $	*/
@@ -42,7 +42,16 @@
  * Prototypes for read-ahead/write-behind subroutines for tftp user and
  * server.
  */
+#ifndef TFTPSUBS_H
+#define TFTPSUBS_H
+
 #include <stdlib.h>
+#include <stdio.h>
+#include <signal.h>
+#include <setjmp.h>
+#include "../config.h"
+
+struct tftphdr;
 
 struct tftphdr *r_init(void);
 void	read_ahead(FILE *, int);
@@ -62,3 +71,25 @@ extern int segsize;
  */
 extern void *xmalloc(size_t);
 extern char *xstrdup(const char *);
+
+/*
+ * Signal-related stuff
+ */
+void bsd_signal(int, void (*)(int));
+
+#ifndef HAVE_SIGSETJMP
+#define sigsetjmp(x,y)  setjmp(x)
+#define siglongjmp(x,y) longjmp(x,y)
+#define sigjmp_buf jmp_buf
+#endif
+
+/*
+ * How to annotate unused variables
+ */
+#ifdef __GNUC__
+#define UNUSED __attribute__((unused))
+#else
+#define UNUSED
+#endif
+
+#endif
